Determine if value(s) are NOT in another value or set.

not_in(x, y)

Arguments

x

single value or vector

y

single value or vector

Details

This is a helper function to see if values are NOT IN other values. Mainly this helps me quickly check without having to negate the This is a test to see if this function is helpful, and might be deleted. later on.

Examples

library(learylib) library(dplyr)
#> #> Attaching package: 'dplyr'
#> The following objects are masked from 'package:stats': #> #> filter, lag
#> The following objects are masked from 'package:base': #> #> intersect, setdiff, setequal, union
"test" %>% not_in(c("quiz", "homework"))
#> [1] TRUE
"test" %>% not_in(c("quiz", "test"))
#> [1] FALSE