A function to clear my .Rprofile

rprofile_clear(local.rprofile.path = "~/.Rprofile")

Arguments

local.rprofile.path

character value. Path to local .Rprofile. Defaults to common "~/.Rprofile".

Details

This function takes an existing Rprofile file and deletes the text. Note that it checks for the file at the common "~/.Rprofile" location, but can be manually adjusted for projects, etc.

Examples

library(learylib) rprofile_clear() # using default settings
#> Rprofile cleared