R/copy_to_clipboard.R
copy_to_clipboard.RdA function to update my .Rprofile from a version on Github
copy_to_clipboard(data.input, row.names.input = FALSE)
| data.input | data.frame. Data frame desired to by moved outside of R |
|---|---|
| row.names.input | logical. Should row names be included in in the output data frame. Defaults to FALSE. |
This function takes a data frame and copies it to the computer clipboard, allowing user to paste the data into excel, word, email, etc.