Determine if value(s) are NOT in another value or set.
not_in(x, y)
| x | single value or vector |
|---|---|
| y | single value or vector |
This is a helper function to see if values are NOT IN other values. Mainly this helps me quickly check without having to negate the This is a test to see if this function is helpful, and might be deleted. later on.
#> #>#> #> #>#> #> #>#> [1] TRUE#> [1] FALSE