Determine if value(s) are NOT NA
not_na(x)
| x | single value or vector |
|---|
This is a helper function to check for NOT NA. This is mainly to hel me quickly check without having to negate 'is.na' with '!is.na(x)'. This is a test to see if this function is helpful, and might be deleted later on.
#> [1] TRUE TRUE TRUE FALSE