Google search R error messages
search_last_error(additonal.term = NULL)
| additonal.term | character. Additional text to add to Google search after "R". |
|---|
This function takes the last error in my R session and creates a Google search for an answer. 93 percent of the time this will be to remember something I have done in `ggplot2` 1,573 times before but forgot. For example, adding "ggplot" will search 'R, ggplot, error message here'. Heavily borrowed from & influenced from David Robinson's github.