Minimal ggplot2 theme
theme_leary(base_size = 12, ...)
| base_size | base font size |
|---|---|
| ... | Other arguments passed to |
This is a draft version and will be updated as I improve my package development skills. It does not currently match the Roboto font used in my rmarkdown template (leary_html), but currently uses Helvetica font.
library(ggplot2) ggplot(mtcars, aes(wt, mpg)) + geom_point() + labs(title = "A basic example plot", subtitle = "A little more detail in substitle?") + theme_leary()